package org.framework.lazy.cloud.network.heartbeat.client.netty.proxy.http.advanced;

import io.netty.bootstrap.Bootstrap;
import io.netty.buffer.ByteBuf;
import io.netty.channel.Channel;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioSocketChannel;
import org.framework.lazy.cloud.network.heartbeat.common.NettyProxyMsg;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.proxy.http.AbstractHttpClientProxyClientTypeAdvanced;
import org.framework.lazy.cloud.network.heartbeat.common.decoder.TransferDecoder;
import org.framework.lazy.cloud.network.heartbeat.common.encoder.TransferEncoder;
import org.framework.lazy.cloud.network.heartbeat.common.utils.ChannelAttributeKeyUtils;
import org.framework.lazy.cloud.network.heartbeat.protocol.handler.NettyHttpProxyBackendHandler;
import org.framework.lazy.cloud.network.heartbeat.protocol.route.ProxyRoute;
import org.framework.lazy.cloud.network.heartbeat.protocol.route.RouteContext;
import org.framework.lazy.cloud.network.heartbeat.protocol.route.RouteType;

/**
 * http 远程代理
 * 客户端：客户端远程到服务端、客户端远程到客户端
 *
 */
public class ClientHandleHttpClientProxyClientTypeAdvanced extends
        AbstractHttpClientProxyClientTypeAdvanced<NettyProxyMsg> {


    /**
     * 处理当前数据
     *
     * @param channel       当前通道
     * @param nettyProxyMsg 通道数据
     */
    @Override
    protected void doHandler(Channel channel, NettyProxyMsg nettyProxyMsg) {

        String targetPortString = nettyProxyMsg.getTargetPortString();
        String targetIpString = nettyProxyMsg.getTargetIpString();
        // 判断代理到客户端还是服务端
        ProxyRoute route = RouteContext.getRoute(targetIpString, targetPortString);
        if(RouteType.CLIENT_PROXY_SEVER.equals(route.getRouteType())){
            // 服务端代理

        }else if (RouteType.CLIENT_PROXY_CLIENT.equals(route.getRouteType())){
            // 客户端代理
        }
        Bootstrap b = new Bootstrap();
        b.group(channel.eventLoop())
                .channel(NioSocketChannel.class)
                .handler(new ChannelInitializer<SocketChannel>() {
                    @Override
                    protected void initChannel(SocketChannel ch) throws Exception {
                        ch.pipeline().addLast(
                                new TransferDecoder(Integer.MAX_VALUE, 1024 * 1024 * 10),
                                new TransferEncoder(),
                                new NettyHttpProxyBackendHandler()
                        );
                    }
                });
        ChannelFuture f = b.connect(targetIpString, Integer.parseInt(targetPortString));
        Channel proxyChannel = f.channel();
        f.addListener((ChannelFutureListener) future -> {
            if (future.isSuccess()) {
                ChannelAttributeKeyUtils.buildNextChannel(proxyChannel, channel);
                ChannelAttributeKeyUtils.buildNextChannel(channel, proxyChannel);
                ByteBuf buf = channel.config().getAllocator().buffer(nettyProxyMsg.getData().length);
                buf.writeBytes(nettyProxyMsg.getData());
                proxyChannel.writeAndFlush(buf);
            } else {
                channel.close();
            }
        });
    }
}
